;; utils.el -- Steve Molitor's elisp utility functions


(defun fill-template (tmplFile &rest tagVals)
  "Insert template file into current buffer, replace tags with client supplied values."
    (insert-file-contents tmplFile 'nil)
    (while tagVals
      (save-excursion
	(while (search-forward (car tagVals) 'nil 't)
	  (replace-match (car (cdr tagVals)))))
      (setq tagVals (nthcdr 2 tagVals))))


(defun ext-match (ext &optional buf)
  "Return true if extension of buffer file name equal ext, else return nil."
    (or buf (setq buf (current-buffer)))
    (if (not buffer-file-name)
	 (error "Buffer contains no associated file"))
    (let* ((file-name (file-name-nondirectory (buffer-file-name buf)))
	   (pos (string-match "\\." file-name)))
      (if pos
	  (equal (substring file-name (1+ pos)) ext)
	nil)))


(defun replace-in-string (s c1 c2)
  "Return string where every occurrence of character c1 in string s is replaced with character c2."
  (let ((temp (copy-sequence s))
	 (i 0))
    (while (< i (length temp))
      (if (equal (aref temp i) c1)
	  (aset temp i c2))
      (setq i (1+ i)))
    temp))


(defun escapify-regx-char (s)
  "Put escape character in front of (some) regular expression special characters."
  (let ((regx-chars '(?* ?+ ??))
        new-s
        (i 0))
    (while (< i (length s))
      (if (member (aref s i) regx-chars)
          (setq new-s (concat new-s "\\")))
      (setq new-s (concat new-s (char-to-string (aref s i))))
      (setq i (1+ i)))
    new-s))


;;; provide
(provide 'utils)


;;; utils.el ends here

